"""
ACH SHT1x Click RPi Demo
V1.0 - 2014-08-24 4.22pm

Demonstrates a MikroE SHT1x click board running on a Raspberry PI using a MikroE Pi Click Shield

SHT1X Click > Pi Click Shield > Raspberry Pi Interfacing
MikroBus I2C SDA = RPI Pin 3 = dataPin
MikroBus I2C SCL = RPI Pin 5 = clkPin


SHT1x Click Board Demo Ported by Andrew Hazelden
Email: andrew@andrewhazelden.com
Blog: http://www.andrewhazelden.com
Twitter: https://www.twitter.com/andrewhazelden

Based upon the code and library from the pypi.python.org website:
https://pypi.python.org/pypi/rpiSht1x/1.2

rpiSht1x Created by Luca Nobili (lunobili):
https://bitbucket.org/lunobili/rpisht1x

Download the rpiSht1x library from:
https://pypi.python.org/packages/source/r/rpiSht1x/rpiSht1x-1.2.tar.gz



Note: This code has to be run as a root user for access to the GPIO pins.


Admin Privileges Required
Scripts that use the GPIO and I2C hardware interfaces need to be run with sudo since GPIO reading requires admin privileges on Linux.

That means you need to run the sht1x_click.py demo python script using:
sudo python sht1x_click.py


Installation Procedure

Step 1. Download the Library
cd ~/
wget https://pypi.python.org/packages/source/r/rpiSht1x/rpiSht1x-1.2.tar.gz


Step 2. Expand the file in the Raspbian File Manager using the right click "Expand Here" contextual menu item.


Step 3. Install the rpiSht1x library using:
cd rpiSht1x-1.2
sudo python setup.py install


Step 4. To verify the library is installed correctly check if the SHT1x module is listed in the python interactive help section:
python
>>> help('sht1x')

To quit the python interactive session type:
>>> exit()


Step 5. Now, let's run the sht1x_click.py script from the terminal:
sudo python sht1x_click.py

"""

print 'SHT1x Click Demo'
print 'Version 1.0 - 2014-08-24'
print '-------------------------'
print 'Press Control+D to Quit'

# SHT1x Click Board Pin Mapping
# MikroBus SDA = RPI Pin 3 = dataPin
dataPin = 3
# MikroBus SCL = RPI Pin 5 = clkPin
clkPin = 5

# Used to add delay to the program
from time import sleep

# Init the I2C based SHT1x click board
from sht1x.Sht1x import Sht1x as SHT1x

sht1x = SHT1x(dataPin, clkPin, SHT1x.GPIO_BOARD)

# Run the main code
while True:
  # Read the sht1x live values
  temperature = sht1x.read_temperature_C()
  humidity = sht1x.read_humidity()
  dewPoint = sht1x.calculate_dew_point(temperature, humidity)

  # Display the formatted values with 2 digits of floating point precision
  print(u"Temperature: {0:.2f}\N{DEGREE SIGN}C Humidity: {1:.2f}% Dew Point: {2:.2f}\N{DEGREE SIGN}C".format(temperature, humidity, dewPoint))

  # Wait one second between updates to slow down the scroll rate
  sleep(1)



